@@ -25,9 +25,10 @@
 #define __GTK_SOURCE_VIEW_H__
 
 #include <gtk/gtk.h>
-#include <gtk/gtktextview.h>
 
 #include <gtksourceview/gtksourcebuffer.h>
+#include <gtksourceview/gtksourcecompletion.h>
+#include <gtksourceview/gtksourcegutter.h>
 
 G_BEGIN_DECLS
 
@@ -38,6 +39,18 @@ G_BEGIN_DECLS
 #define GTK_IS_SOURCE_VIEW_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_TYPE_SOURCE_VIEW))
 #define GTK_SOURCE_VIEW_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_SOURCE_VIEW, GtkSourceViewClass))
 
+/**
+ * GtkSourceViewGutterPosition:
+ * @GTK_SOURCE_VIEW_GUTTER_POSITION_LINES: the gutter position of the lines
+ * renderer
+ * @GTK_SOURCE_VIEW_GUTTER_POSITION_MARKS: the gutter position of the marks
+ * renderer
+ **/
+typedef enum
+{
+	GTK_SOURCE_VIEW_GUTTER_POSITION_LINES = -30,
+	GTK_SOURCE_VIEW_GUTTER_POSITION_MARKS = -20
+} GtkSourceViewGutterPosition;
 
 typedef struct _GtkSourceView GtkSourceView;
 typedef struct _GtkSourceViewClass GtkSourceViewClass;
@@ -57,12 +70,16 @@ struct _GtkSourceViewClass
 
 	void (*undo) (GtkSourceView *view);
 	void (*redo) (GtkSourceView *view);
+	void (*line_mark_activated) (GtkSourceView *view, 
+	                             GtkTextIter   *iter,
+	                             GdkEvent      *event);
+	void (*show_completion) (GtkSourceView *view);
+	void (*move_lines) (GtkSourceView *view,
+	                    gboolean       copy,
+	                    gint           step);
 
 	/* Padding for future expansion */
 	void (*_gtk_source_reserved1) (void);
-	void (*_gtk_source_reserved2) (void);
-	void (*_gtk_source_reserved3) (void);
-	void (*_gtk_source_reserved4) (void);
 };
 
 /**
@@ -95,18 +112,22 @@ typedef enum
  *
  * GtkSourceDrawSpacesFlags determine what kind of spaces whould be drawn.
  */
-/* TODO: it would be nice to have flags to specify to draw
- * just leading/trailing whitespaces */
 typedef enum
 {
 	GTK_SOURCE_DRAW_SPACES_SPACE      = 1 << 0,
 	GTK_SOURCE_DRAW_SPACES_TAB        = 1 << 1,
 	GTK_SOURCE_DRAW_SPACES_NEWLINE    = 1 << 2,
 	GTK_SOURCE_DRAW_SPACES_NBSP       = 1 << 3,
+	GTK_SOURCE_DRAW_SPACES_LEADING    = 1 << 4,
+	GTK_SOURCE_DRAW_SPACES_TEXT       = 1 << 5,
+	GTK_SOURCE_DRAW_SPACES_TRAILING   = 1 << 6,
 	GTK_SOURCE_DRAW_SPACES_ALL        = (GTK_SOURCE_DRAW_SPACES_SPACE   | \
 	                                     GTK_SOURCE_DRAW_SPACES_TAB     | \
 	                                     GTK_SOURCE_DRAW_SPACES_NEWLINE | \
-	                                     GTK_SOURCE_DRAW_SPACES_NBSP)
+	                                     GTK_SOURCE_DRAW_SPACES_NBSP | \
+	                                     GTK_SOURCE_DRAW_SPACES_LEADING | \
+	                                     GTK_SOURCE_DRAW_SPACES_TEXT | \
+	                                     GTK_SOURCE_DRAW_SPACES_TRAILING)
 } GtkSourceDrawSpacesFlags;
 
 
@@ -163,13 +184,33 @@ void 		 gtk_source_view_set_show_line_marks    (GtkSourceView   *view,
 							 gboolean         show);
 gboolean	 gtk_source_view_get_show_line_marks    (GtkSourceView   *view);
 
-void             gtk_source_view_set_mark_category_pixbuf
+#ifndef GTKSOURCEVIEW_DISABLE_DEPRECATED
+void		 gtk_source_view_set_mark_category_pixbuf
+							(GtkSourceView   *view,
+							const gchar      *category,
+							GdkPixbuf        *pixbuf) G_GNUC_DEPRECATED;
+#endif
+
+void             gtk_source_view_set_mark_category_icon_from_pixbuf
 							(GtkSourceView   *view,
 							 const gchar     *category,
 							 GdkPixbuf       *pixbuf);
+
+void             gtk_source_view_set_mark_category_icon_from_stock
+							(GtkSourceView   *view,
+							 const gchar     *category,
+							 const gchar     *stock_id);
+
+void             gtk_source_view_set_mark_category_icon_from_icon_name
+							(GtkSourceView   *view,
+							 const gchar     *category,
+							 const gchar     *name);
+
+#ifndef GTKSOURCEVIEW_DISABLE_DEPRECATED
 GdkPixbuf	*gtk_source_view_get_mark_category_pixbuf
 							(GtkSourceView   *view,
-				       			 const gchar     *category);
+				       			 const gchar     *category) G_GNUC_DEPRECATED;
+#endif
 
 void             gtk_source_view_set_mark_category_background
 							(GtkSourceView   *view,
@@ -180,6 +221,14 @@ gboolean         gtk_source_view_get_mark_category_background
 							 const gchar     *category,
 							 GdkColor        *dest);
 
+/**
+ * GtkSourceViewMarkTooltipFunc:
+ * @mark: the #GtkSourceMark
+ * @user_data: user data pointer which was passed to gtk_source_view_set_mark_category_tooltip_func()
+ *
+ * Function type for setting up a tooltip for #GtkSourceMark.
+ * Returns: a newly-allocated string that is going to be shown as tooltip text.
+ */
 typedef gchar *  (*GtkSourceViewMarkTooltipFunc)	(GtkSourceMark	*mark,
 							 gpointer	 user_data);
 void             gtk_source_view_set_mark_category_tooltip_func
@@ -213,5 +262,11 @@ void		 gtk_source_view_set_draw_spaces	(GtkSourceView   *view,
 GtkSourceDrawSpacesFlags
 		gtk_source_view_get_draw_spaces		(GtkSourceView   *view);
 
+GtkSourceCompletion *
+		gtk_source_view_get_completion		(GtkSourceView   *view);
+
+GtkSourceGutter *gtk_source_view_get_gutter		(GtkSourceView     *view,
+                                                         GtkTextWindowType  window_type);
+
 G_END_DECLS
 #endif				/* end of SOURCE_VIEW_H__ */
